# Chonkie

Wraps [Chonkie](https://github.com/bhavnicksm/chonkie) for chunking.

## Usage

```python
--8<-- "sieves/tests/docs/test_preprocessing_usage.py:chonkie-usage"
```

---

::: sieves.tasks.preprocessing.chunking.chonkie_
